[^:]*: Assembler messages:
[^:]*:3: Error: immediate value out of range -- `vcvt.f64.u16 d1,d1,#-1'
[^:]*:4: Error: immediate value out of range -- `vcvt.f64.u16 d1,d1,#65535'
[^:]*:5: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.f64.u16 d1,d1,#17'
[^:]*:6: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.f64.u32 d1,d1,#0'
[^:]*:7: Error: immediate value out of range -- `vcvt.f64.u32 d1,d1,#33'
[^:]*:9: Error: immediate value out of range -- `vcvt.f32.u16 s1,s1,#-1'
[^:]*:10: Error: immediate value out of range -- `vcvt.f32.u16 s1,s1,#65535'
[^:]*:11: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.f32.u16 s1,s1,#17'
[^:]*:12: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.f32.u32 s1,s1,#0'
[^:]*:13: Error: immediate value out of range -- `vcvt.f32.u32 s1,s1,#33'
[^:]*:15: Error: immediate value out of range -- `vcvt.u16.f64 d1,d1,#-1'
[^:]*:16: Error: immediate value out of range -- `vcvt.u16.f64 d1,d1,#65535'
[^:]*:17: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.u16.f64 d1,d1,#17'
[^:]*:18: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.u32.f64 d1,d1,#0'
[^:]*:19: Error: immediate value out of range -- `vcvt.u32.f64 d1,d1,#33'
[^:]*:21: Error: immediate value out of range -- `vcvt.u16.f32 s1,s1,#-1'
[^:]*:22: Error: immediate value out of range -- `vcvt.u16.f32 s1,s1,#65535'
[^:]*:23: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.u16.f32 s1,s1,#17'
[^:]*:24: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.u32.f32 s1,s1,#0'
[^:]*:25: Error: immediate value out of range -- `vcvt.u32.f32 s1,s1,#33'
[^:]*:27: Error: immediate value out of range -- `vcvt.f64.s16 d1,d1,#-1'
[^:]*:28: Error: immediate value out of range -- `vcvt.f64.s16 d1,d1,#65535'
[^:]*:29: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.f64.s16 d1,d1,#17'
[^:]*:30: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.f64.s32 d1,d1,#0'
[^:]*:31: Error: immediate value out of range -- `vcvt.f64.s32 d1,d1,#33'
[^:]*:33: Error: immediate value out of range -- `vcvt.f32.s16 s1,s1,#-1'
[^:]*:34: Error: immediate value out of range -- `vcvt.f32.s16 s1,s1,#65535'
[^:]*:35: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.f32.s16 s1,s1,#17'
[^:]*:36: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.f32.s32 s1,s1,#0'
[^:]*:37: Error: immediate value out of range -- `vcvt.f32.s32 s1,s1,#33'
[^:]*:39: Error: immediate value out of range -- `vcvt.s16.f64 d1,d1,#-1'
[^:]*:40: Error: immediate value out of range -- `vcvt.s16.f64 d1,d1,#65535'
[^:]*:41: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.s16.f64 d1,d1,#17'
[^:]*:42: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.s32.f64 d1,d1,#0'
[^:]*:43: Error: immediate value out of range -- `vcvt.s32.f64 d1,d1,#33'
[^:]*:45: Error: immediate value out of range -- `vcvt.s16.f32 s1,s1,#-1'
[^:]*:46: Error: immediate value out of range -- `vcvt.s16.f32 s1,s1,#65535'
[^:]*:47: Error: immediate value out of range, expected range \[0, 16\] -- `vcvt.s16.f32 s1,s1,#17'
[^:]*:48: Error: immediate value out of range, expected range \[1, 32\] -- `vcvt.s32.f32 s1,s1,#0'
[^:]*:49: Error: immediate value out of range -- `vcvt.s32.f32 s1,s1,#33'
