MACHINE=
SCRIPT_NAME=elfxgate
OUTPUT_FORMAT="elf32-xgate"
ROM_START_ADDR=0x08000
ROM_SIZE=0x8000
RAM_START_ADDR=0x01100
RAM_SIZE=0x6F00
EEPROM_START_ADDR=0x0800
EEPROM_SIZE=2048
TEXT_MEMORY=text
DATA_MEMORY=data
EEPROM_MEMORY=eeprom
ARCH=xgate
MAXPAGESIZE=32
EMBEDDED=yes
GENERIC_BOARD=no
TEMPLATE_NAME=elf32
EXTRA_EM_FILE=
