; Test C64x+ dinc compact instruction format
	.text
dinc:
	nop
	.align 16
	nop
	.align 16
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0c05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefe00000
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefe8c000
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefe9c000
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefeac000
	.short 0x0e04
	.short 0x1e04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefebc000
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefecc000
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefedc000
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefeec000
	.short 0x0c04
	.short 0x1c04
	.short 0x0e04
	.short 0x0c0c
	.short 0x0c05
	.short 0x1c05
	.short 0x0e05
	.short 0x0c0d
	.short 0x1c05
	.short 0x0e05
	.short 0x1e0d
	.short 0x2e0d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefefc000
	.short 0x0c14
	.short 0x1c14
	.short 0x0e14
	.short 0x0c1c
	.short 0x0c15
	.short 0x1c15
	.short 0x0e15
	.short 0x0c1d
	.short 0x1c15
	.short 0x0e15
	.short 0x1e1d
	.short 0x2e1d
	.short 0x3e1d
	.short 0x2e1d
	.word  0xefefc000
