.*: Assembler messages:
.*:15: Error: invalid operands `addu16 \$12,\$14'
.*:18: Error: unrecognized 16-bit version of microMIPS opcode `add16\.ps \$f2,\$f4'
.*:22: Error: unrecognized 32-bit version of microMIPS opcode `addiusp32 256'
.*:25: Error: unrecognized opcode `jar \$23'
.*:26: Error: unrecognized opcode `jar16 \$23'
.*:27: Error: unrecognized opcode `jar32 \$23'
.*:41: Error: invalid operands `jalr16 \$30,\$26'
.*:50: Error: invalid operands `beqz16 \$27,bar'
.*:58: Warning: wrong size instruction in a 32-bit branch delay slot
.*:66: Warning: wrong size instruction in a 16-bit branch delay slot
.*:70: Error: unrecognized 16-bit version of microMIPS opcode `add16\.ps \$f2,\$f4'
.*:74: Warning: wrong size instruction in a 16-bit branch delay slot
.*:76: Error: unrecognized 16-bit version of microMIPS opcode `add16\.ps \$f2,\$f4'
.*:77: Warning: wrong size instruction in a 16-bit branch delay slot
.*:78: Warning: wrong size instruction in a 16-bit branch delay slot
.*:80: Warning: wrong size instruction in a 32-bit branch delay slot
.*:82: Warning: wrong size instruction in a 32-bit branch delay slot
.*:84: Error: unrecognized 32-bit version of microMIPS opcode `addiusp32 256'
.*:90: Error: unrecognized 32-bit version of microMIPS opcode `addiusp32 256'
.*:95: Warning: macro instruction expanded into a wrong size instruction in a 16-bit branch delay slot
.*:95: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:98: Warning: wrong size instruction in a 32-bit branch delay slot
.*:104: Error: unrecognized 16-bit version of microMIPS opcode `add16\.ps \$f2,\$f4'
.*:105: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:108: Warning: wrong size instruction in a 32-bit branch delay slot
.*:110: Warning: wrong size instruction in a 32-bit branch delay slot
.*:112: Error: unrecognized 32-bit version of microMIPS opcode `addiusp32 256'
.*:120: Error: operand 3 out of range `sll16 \$2,\$3,13'
.*:123: Error: invalid operands `sll16 \$10,\$11,5'
.*:128: Error: unrecognized 16-bit version of microMIPS opcode `dsll16 \$2,\$3,5'
.*:130: Error: unrecognized 16-bit version of microMIPS opcode `dsll3216 \$2,\$3,5'
.*:133: Error: unrecognized 16-bit version of microMIPS opcode `dsll16 \$2,\$3,13'
.*:135: Error: unrecognized 16-bit version of microMIPS opcode `dsll3216 \$2,\$3,13'
.*:138: Error: unrecognized 16-bit version of microMIPS opcode `dsll16 \$10,\$11,5'
.*:140: Error: unrecognized 16-bit version of microMIPS opcode `dsll3216 \$10,\$11,5'
.*:145: Error: operand 3 out of range `addiu16 \$2,\$4,5'
.*:146: Error: operand 3 out of range `addiu16 \$2,\$4,7'
.*:149: Error: operand 3 out of range `andi16 \$2,\$4,5'
.*:154: Error: operand 1 out of range `addiusp16 4'
.*:155: Error: operand 1 out of range `addiusp16 7'
.*:157: Error: operand 1 out of range `addiusp16 10'
.*:160: Error: operand 1 out of range `addiusp16 1032'
.*:162: Error: operand 1 out of range `addiusp16 -1036'
