#define BFD_VERSION_DATE 20131116
#define BFD_VERSION 223900000
#define BFD_VERSION_STRING  "(GNU Binutils for Ubuntu) " "2.23.90.20131116"
#define REPORT_BUGS_TO "<http://www.sourceware.org/bugzilla/>"
