        .text
        .global main
main:
	##########################################
	# excp svc/dvz/flg/bpt/trc/und/iad/dbg/ise
	##########################################
	excp	svc
	excp	dvz
	excp	flg
	excp	bpt
	excp	trc
	excp	und
	excp	iad
	excp	dbg
	excp	ise
