% { dg-do assemble { target mmix-*-* } }
 SWYM 256*256*256	% { dg-error "invalid operands" "" }
 SWYM -1		% { dg-error "invalid operands" "" }
 SWYM 99,256*256	% { dg-error "invalid operands" "" }
 SWYM 99,-1		% { dg-error "invalid operands" "" }
 SWYM 256,1,2		% { dg-error "invalid operands" "" }
 SWYM 1,256,2		% { dg-error "invalid operands" "" }
 SWYM 1,2,256		% { dg-error "invalid operands" "" }
 SWYM -1,1,2		% { dg-error "invalid operands" "" }
 SWYM 1,-1,2		% { dg-error "invalid operands" "" }
 SWYM 1,2,-1		% { dg-error "invalid operands" "" }
 SWYM 256,1		% { dg-error "invalid operands" "" }
 SWYM -1,1		% { dg-error "invalid operands" "" }
 SWYM 1,2,3,4		% { dg-error "invalid operands" "" }
 SWYM 1,2,3,4,5		% { dg-error "invalid operands" "" }
