[^:]*: Assembler messages:
[^:]*:4:.*\.bundle_lock is meaningless without \.bundle_align_mode
[^:]*:6:.*\.bundle_unlock without preceding \.bundle_lock
[^:]*:11:.*single instruction is [0-9]+ bytes long but \.bundle_align_mode limit is [0-9]+
[^:]*:18:.*\.bundle_lock sequence at [0-9]+ bytes but \.bundle_align_mode limit is [0-9]+ bytes
[^:]*:19:.*\.bundle_lock sequence is [0-9]+ bytes, but bundle size only [0-9]+
[^:]*:26:.*cannot change section or subsection inside \.bundle_lock
[^:]*:31:.*cannot change \.bundle_align_mode inside \.bundle_lock
[^:]*:36:.*\.bundle_unlock without preceding \.bundle_lock
[^:]*:39:.*\.bundle_lock with no matching \.bundle_unlock
