.*: Assembler messages:
.*:7: Warning: IT blocks containing 32-bit Thumb instructions are deprecated in ARMv8
.*:15: Warning: IT blocks containing more than one conditional instruction are deprecated in ARMv8
.*:20: Warning: IT blocks containing more than one conditional instruction are deprecated in ARMv8
.*:30: Warning: IT blocks containing 32-bit Thumb instructions are deprecated in ARMv8
.*:36: Warning: IT blocks containing more than one conditional instruction are deprecated in ARMv8
.*:40: Warning: IT blocks containing 16-bit Thumb instructions of the following class are deprecated in ARMv8: Short branches, Undefined, SVC, LDM/STM
.*:43: Warning: IT blocks containing 16-bit Thumb instructions of the following class are deprecated in ARMv8: Miscellaneous 16-bit instructions
.*:49: Warning: IT blocks containing 16-bit Thumb instructions of the following class are deprecated in ARMv8: Literal loads
.*:52: Warning: IT blocks containing 16-bit Thumb instructions of the following class are deprecated in ARMv8: Hi-register ADD, MOV, CMP, BX, BLX using pc
.*:55: Warning: IT blocks containing 16-bit Thumb instructions of the following class are deprecated in ARMv8: Short branches, Undefined, SVC, LDM/STM
.*:55: Error: r15 not allowed here -- `addeq r0,pc,pc'
.*:58: Warning: IT blocks containing 16-bit Thumb instructions of the following class are deprecated in ARMv8: Short branches, Undefined, SVC, LDM/STM
.*:58: Error: r15 not allowed here -- `addeq pc,r0,r0'
