.*: Assembler messages:
.*:3: Error: the source register must not be \$31.*
.*:4: Error: the source register must not be \$31.*
.*:6: Error: the source register must not be \$31.*
.*:7: Error: the source register must not be \$31.*
.*:9: Error: the source register must not be \$31.*
.*:10: Error: the source register must not be \$31.*
