.*: Assembler messages:
.*:578: Warning: divide by zero
.*:581: Warning: divide by zero
.*:594: Warning: divide by zero
.*:1559: Warning: divide by zero
.*:1562: Warning: divide by zero
.*:1575: Warning: divide by zero
.*:2622: Warning: branch bge is always true
.*:2625: Warning: branch bgeu is always true
.*:2634: Warning: branch bgeu is always true
.*:2709: Warning: branch ble is always true
.*:2724: Warning: branch bleu is always true
.*:2730: Warning: branch bleu is always true
.*:2733: Warning: branch bleu is always true
.*:2832: Warning: branch bgel is always true
.*:2835: Warning: branch bgeul is always true
.*:2844: Warning: branch bgeul is always true
.*:2919: Warning: branch blel is always true
.*:2934: Warning: branch bleul is always true
.*:2940: Warning: branch bleul is always true
.*:2943: Warning: branch bleul is always true
.*:4759: Warning: divide by zero
.*:4762: Warning: divide by zero
.*:4775: Warning: divide by zero
.*:5180: Warning: divide by zero
.*:5190: Warning: divide by zero
.*:5200: Warning: divide by zero
