[^:]*: Assembler messages:
[^:]*:4: Warning: using r15 results in unpredictable behaviour
[^:]*.s:5: Warning: using r15 results in unpredictable behaviour
[^:]*.s:6: Warning: using r15 results in unpredictable behaviour
[^:]*.s:7: Warning: using r15 results in unpredictable behaviour
[^:]*.s:8: Warning: using r15 results in unpredictable behaviour
[^:]*.s:9: Warning: using r15 results in unpredictable behaviour
[^:]*.s:12: Warning: using r13 results in unpredictable behaviour
[^:]*.s:13: Warning: using r15 results in unpredictable behaviour
[^:]*.s:14: Warning: using r13 results in unpredictable behaviour
[^:]*.s:15: Warning: using r15 results in unpredictable behaviour
[^:]*.s:16: Warning: using r13 results in unpredictable behaviour
[^:]*.s:17: Warning: using r15 results in unpredictable behaviour
