#objdump: -dr

dump\.o:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	7f 80                         	suntil\.b
   2:	7f 81                         	suntil\.w
   4:	7f 82                         	suntil\.l
