	.text

	mtmas1		5

	mtcsrr0		1
	mtcsrr1		2

	mfivor0		5
	mfivor1		5
	mfivor2		5
	mfivor3		5
	mfivor4		5
	mfivor5		5
	mfivor6		5
	mfivor7		5
	mfivor8		5
	mfivor9		5
	mfivor10	5
	mfivor11	5
	mfivor12	5
	mfivor13	5
	mfivor14	5
	mfivor15	5

	mtsprg		0, 10
	mtsprg		1, 10
	mtsprg		2, 10
	mtsprg		3, 10
	mtsprg		4, 10
	mtsprg		5, 10
	mtsprg		6, 10
	mtsprg		7, 10

	mtsprg0		10
	mtsprg1		10
	mtsprg2		10
	mtsprg3		10
	mtsprg4		10
	mtsprg5		10
	mtsprg6		10
	mtsprg7		10

	mfsprg		9, 0
	mfsprg		9, 1
	mfsprg		9, 2
	mfsprg		9, 3
	mfsprg		9, 4 
	mfsprg		9, 5 
	mfsprg		9, 6 
	mfsprg		9, 7

	mfsprg0		9
	mfsprg1		9
	mfsprg2		9
	mfsprg3		9
	mfsprg4		9
	mfsprg5		9
	mfsprg6		9
	mfsprg7		9
